==> huaweicloudsdklive-3.1.73-py2.py3-none-any.whl: huaweicloudsdklive/v1/model/update_domain_https_cert_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateDomainHttpsCertRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'domain': 'str',
        'body': 'DomainHttpsCertInfo'
    }

    attribute_map = {
        'domain': 'domain',
        'body': 'body'
    }

    def __init__(self, domain=None, body=None):
        """UpdateDomainHttpsCertRequest

        The model defined in huaweicloud sdk

        :param domain: 直播播放域名
        :type domain: str
        :param body: Body of the UpdateDomainHttpsCertRequest
        :type body: :class:`huaweicloudsdklive.v1.DomainHttpsCertInfo`
        """
        
        

        self._domain = None
        self._body = None
        self.discriminator = None

        self.domain = domain
        if body is not None:
            self.body = body

    @property
    def domain(self):
        """Gets the domain of this UpdateDomainHttpsCertRequest.

        直播播放域名

        :return: The domain of this UpdateDomainHttpsCertRequest.
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this UpdateDomainHttpsCertRequest.

        直播播放域名

        :param domain: The domain of this UpdateDomainHttpsCertRequest.
        :type domain: str
        """
        self._domain = domain

    @property
    def body(self):
        """Gets the body of this UpdateDomainHttpsCertRequest.

        :return: The body of this UpdateDomainHttpsCertRequest.
        :rtype: :class:`huaweicloudsdklive.v1.DomainHttpsCertInfo`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this UpdateDomainHttpsCertRequest.

        :param body: The body of this UpdateDomainHttpsCertRequest.
        :type body: :class:`huaweicloudsdklive.v1.DomainHttpsCertInfo`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateDomainHttpsCertRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdklive-3.1.155-py2.py3-none-any.whl: huaweicloudsdklive/v1/model/update_domain_https_cert_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateDomainHttpsCertRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'domain': 'str',
        'body': 'DomainHttpsCertInfo'
    }

    attribute_map = {
        'domain': 'domain',
        'body': 'body'
    }

    def __init__(self, domain=None, body=None):
        r"""UpdateDomainHttpsCertRequest

        The model defined in huaweicloud sdk

        :param domain: 直播播放域名
        :type domain: str
        :param body: Body of the UpdateDomainHttpsCertRequest
        :type body: :class:`huaweicloudsdklive.v1.DomainHttpsCertInfo`
        """
        
        

        self._domain = None
        self._body = None
        self.discriminator = None

        self.domain = domain
        if body is not None:
            self.body = body

    @property
    def domain(self):
        r"""Gets the domain of this UpdateDomainHttpsCertRequest.

        直播播放域名

        :return: The domain of this UpdateDomainHttpsCertRequest.
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        r"""Sets the domain of this UpdateDomainHttpsCertRequest.

        直播播放域名

        :param domain: The domain of this UpdateDomainHttpsCertRequest.
        :type domain: str
        """
        self._domain = domain

    @property
    def body(self):
        r"""Gets the body of this UpdateDomainHttpsCertRequest.

        :return: The body of this UpdateDomainHttpsCertRequest.
        :rtype: :class:`huaweicloudsdklive.v1.DomainHttpsCertInfo`
        """
        return self._body

    @body.setter
    def body(self, body):
        r"""Sets the body of this UpdateDomainHttpsCertRequest.

        :param body: The body of this UpdateDomainHttpsCertRequest.
        :type body: :class:`huaweicloudsdklive.v1.DomainHttpsCertInfo`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateDomainHttpsCertRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
